@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.02';
+$VERSION = '1.04';
 
 # APE metadata blocks
 %Image::ExifTool::APE::Main = (
@@ -24,7 +24,7 @@ $VERSION = '1.02';
         Tags found in Monkey's Audio (APE) information.  Only a few common tags are
         listed below, but ExifTool will extract any tag found.  ExifTool supports
         APEv1 and APEv2 tags, as well as ID3 information in APE files, and will also
-        read APE metadata from MP3 files.
+        read APE metadata from MP3 and MPC files.
     },
     Album   => { },
     Artist  => { },
@@ -83,7 +83,9 @@ sub MakeTag($$)
     # remove invalid characters in tag name and capitalize following letters
     $name =~ s/[^\w-]+(.?)/\U$1/sg;
     $name =~ s/([a-z0-9])_([a-z])/$1\U$2/g;
-    AddTagToTable($tagTablePtr, $tag, { Name => $name });
+    my %tagInfo = ( Name => $name );
+    $tagInfo{Groups} = { 2 => 'Preview' } if $tag =~ /^Cover Art/ and $tag !~ /Desc$/;
+    AddTagToTable($tagTablePtr, $tag, \%tagInfo);
 }
 
 #------------------------------------------------------------------------------
@@ -93,25 +95,25 @@ sub MakeTag($$)
 # Returns: 1 on success, 0 if this wasn't a valid APE file
 sub ProcessAPE($$)
 {
-    my ($exifTool, $dirInfo) = @_;
+    my ($et, $dirInfo) = @_;
 
     # must first check for leading/trailing ID3 information
-    unless ($exifTool->{DoneID3}) {
+    unless ($$et{DoneID3}) {
         require Image::ExifTool::ID3;
-        Image::ExifTool::ID3::ProcessID3($exifTool, $dirInfo) and return 1;
+        Image::ExifTool::ID3::ProcessID3($et, $dirInfo) and return 1;
     }
     my $raf = $$dirInfo{RAF};
-    my $verbose = $exifTool->Options('Verbose');
+    my $verbose = $et->Options('Verbose');
     my ($buff, $i, $header, $tagTablePtr, $dataPos, $oldIndent);
 
-    $exifTool->{DoneAPE} = 1;
+    $$et{DoneAPE} = 1;
 
     # check APE signature and process audio information
     # unless this is some other type of file
-    unless ($exifTool->{VALUE}->{FileType}) {
+    unless ($$et{VALUE}{FileType}) {
         $raf->Read($buff, 32) == 32 or return 0;
         $buff =~ /^(MAC |APETAGEX)/ or return 0;
-        $exifTool->SetFileType();
+        $et->SetFileType();
         SetByteOrder('II');
 
         if ($buff =~ /^APETAGEX/) {
@@ -133,7 +135,7 @@ sub ProcessAPE($$)
                     }
                 }
             }
-            $exifTool->ProcessDirectory( { DataPt => \$buff }, $table) if $table;
+            $et->ProcessDirectory( { DataPt => \$buff }, $table) if $table;
         }
     }
     # look for APE trailer unless we already found an APE header
@@ -141,7 +143,7 @@ sub ProcessAPE($$)
         # look for the APE trailer footer...
         my $footPos = -32;
         # (...but before the ID3v1 trailer if it exists)
-        $footPos -= 128 if $exifTool->{DoneID3} == 2;
+        $footPos -= 128 if $$et{DoneID3} == 2;
         $raf->Seek($footPos, 2)     or return 1;
         $raf->Read($buff, 32) == 32 or return 1;
         $buff =~ /^APETAGEX/        or return 1;
@@ -158,10 +160,10 @@ sub ProcessAPE($$)
         $raf->Read($buff, $size) == $size)
     {
         if ($verbose) {
-            $oldIndent = $$exifTool{INDENT};
-            $$exifTool{INDENT} .= '| ';
-            $exifTool->VerboseDir("APEv$version", $count, $size);
-            $exifTool->VerboseDump(\$buff, DataPos => $raf->Tell() - $size);
+            $oldIndent = $$et{INDENT};
+            $$et{INDENT} .= '| ';
+            $et->VerboseDir("APEv$version", $count, $size);
+            $et->VerboseDump(\$buff, DataPos => $raf->Tell() - $size);
         }
         $tagTablePtr = GetTagTable('Image::ExifTool::APE::Main');
         $dataPos = $raf->Tell() - $size;
@@ -197,11 +199,11 @@ sub ProcessAPE($$)
                     my $t = "$tag Desc";
                     my $v = $1;
                     MakeTag($t, $tagTablePtr) unless $$tagTablePtr{$t};
-                    $exifTool->HandleTag($tagTablePtr, $t, $v);
+                    $et->HandleTag($tagTablePtr, $t, $v);
                 }
             }
         }
-        $exifTool->HandleTag($tagTablePtr, $tag, $val,
+        $et->HandleTag($tagTablePtr, $tag, $val,
             Index => $i,
             DataPt => \$buff,
             DataPos => $dataPos,
@@ -210,8 +212,8 @@ sub ProcessAPE($$)
         );
         $pos += $len;
     }
-    $i == $count or $exifTool->Warn('Bad APE trailer');
-    $$exifTool{INDENT} = $oldIndent if defined $oldIndent;
+    $i == $count or $et->Warn('Bad APE trailer');
+    $$et{INDENT} = $oldIndent if defined $oldIndent;
     return 1;
 }
 
@@ -238,7 +240,7 @@ Currently doesn't parse MAC header unless it is at the start of the file.
 
 =head1 AUTHOR
 
-Copyright 2003-2013, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
